pub struct Faker;Expand description
Generate default fake value for given type using Fake.
Examples
use fake::{Fake, Faker};
let a: Option<usize> = Faker.fake();
// or use turbofish syntax
let b = Faker.fake::<Result<u32, u8>>();
let c: (u8, u32, f32) = Faker.fake();
// can also be combined with other values that implements Fake
let d: (u8, u32, f32) = (1..10, Faker, 2.5..5.5).fake();
let e: [u8; 3] = Faker.fake();
let f: String = Faker.fake();
// it also works for smart pointers and wrappers
let g: std::pin::Pin<String> = Faker.fake();
let h: Box<std::rc::Rc<u8>> = Faker.fake();
let i: std::path::PathBuf = Faker.fake();Trait Implementations
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>> Dummy<Faker> for (A, B, C, D)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>> Dummy<Faker> for (A, B, C, D)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>, K: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J, K)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>, K: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J, K)
Sourceimpl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>, K: Dummy<Faker>, L: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<A: Dummy<Faker>, B: Dummy<Faker>, C: Dummy<Faker>, D: Dummy<Faker>, E: Dummy<Faker>, F: Dummy<Faker>, G: Dummy<Faker>, H: Dummy<Faker>, I: Dummy<Faker>, J: Dummy<Faker>, K: Dummy<Faker>, L: Dummy<Faker>> Dummy<Faker> for (A, B, C, D, E, F, G, H, I, J, K, L)
Sourceimpl Dummy<Faker> for Base64Value
Available on crate feature base64 only.
impl Dummy<Faker> for Base64Value
Available on crate feature
base64 only.Sourceimpl Dummy<Faker> for BigDecimal
Available on crate feature bigdecimal-rs only.
impl Dummy<Faker> for BigDecimal
Available on crate feature
bigdecimal-rs only.Sourceimpl<T> Dummy<Faker> for BinaryHeap<T>
impl<T> Dummy<Faker> for BinaryHeap<T>
Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Coord<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Coord<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for FixedOffset
Available on crate feature chrono only.
impl Dummy<Faker> for FixedOffset
Available on crate feature
chrono only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Geometry<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Geometry<T>
Available on crate feature
geo-types only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for GeometryCollection<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for GeometryCollection<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for HeaderName
Available on crate feature http only.
impl Dummy<Faker> for HeaderName
Available on crate feature
http only.Sourceimpl Dummy<Faker> for HeaderValue
Available on crate feature http only.
impl Dummy<Faker> for HeaderValue
Available on crate feature
http only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Line<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Line<T>
Available on crate feature
geo-types only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for LineString<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for LineString<T>
Available on crate feature
geo-types only.Sourceimpl<T> Dummy<Faker> for LinkedList<T>
impl<T> Dummy<Faker> for LinkedList<T>
Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiLineString<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiLineString<T>
Available on crate feature
geo-types only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiPoint<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiPoint<T>
Available on crate feature
geo-types only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiPolygon<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for MultiPolygon<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for NaiveDateTime
Available on crate feature chrono only.
impl Dummy<Faker> for NaiveDateTime
Available on crate feature
chrono only.Sourceimpl Dummy<Faker> for NonZeroI128
impl Dummy<Faker> for NonZeroI128
Sourceimpl Dummy<Faker> for NonZeroI16
impl Dummy<Faker> for NonZeroI16
Sourceimpl Dummy<Faker> for NonZeroI32
impl Dummy<Faker> for NonZeroI32
Sourceimpl Dummy<Faker> for NonZeroI64
impl Dummy<Faker> for NonZeroI64
Sourceimpl Dummy<Faker> for NonZeroU128
impl Dummy<Faker> for NonZeroU128
Sourceimpl Dummy<Faker> for NonZeroU16
impl Dummy<Faker> for NonZeroU16
Sourceimpl Dummy<Faker> for NonZeroU32
impl Dummy<Faker> for NonZeroU32
Sourceimpl Dummy<Faker> for NonZeroU64
impl Dummy<Faker> for NonZeroU64
Sourceimpl Dummy<Faker> for NonZeroUsize
impl Dummy<Faker> for NonZeroUsize
Sourceimpl Dummy<Faker> for OffsetDateTime
Available on crate feature time only.
impl Dummy<Faker> for OffsetDateTime
Available on crate feature
time only.Sourceimpl Dummy<Faker> for PathAndQuery
Available on crate feature http only.
impl Dummy<Faker> for PathAndQuery
Available on crate feature
http only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Point<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Point<T>
Available on crate feature
geo-types only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Polygon<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Polygon<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for PrimitiveDateTime
Available on crate feature time only.
impl Dummy<Faker> for PrimitiveDateTime
Available on crate feature
time only.Sourceimpl Dummy<Faker> for RandomColor
Available on crate feature random_color only.
impl Dummy<Faker> for RandomColor
Available on crate feature
random_color only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Rect<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Rect<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for SnowflakeDiscordId
Available on crate feature ferroid only.
impl Dummy<Faker> for SnowflakeDiscordId
Available on crate feature
ferroid only.Sourceimpl Dummy<Faker> for SnowflakeInstagramId
Available on crate feature ferroid only.
impl Dummy<Faker> for SnowflakeInstagramId
Available on crate feature
ferroid only.Sourceimpl Dummy<Faker> for SnowflakeMastodonId
Available on crate feature ferroid only.
impl Dummy<Faker> for SnowflakeMastodonId
Available on crate feature
ferroid only.Sourceimpl Dummy<Faker> for SnowflakeTwitterId
Available on crate feature ferroid only.
impl Dummy<Faker> for SnowflakeTwitterId
Available on crate feature
ferroid only.Sourceimpl Dummy<Faker> for SocketAddrV4
impl Dummy<Faker> for SocketAddrV4
Sourceimpl Dummy<Faker> for SocketAddrV6
impl Dummy<Faker> for SocketAddrV6
Sourceimpl Dummy<Faker> for StatusCode
Available on crate feature http only.
impl Dummy<Faker> for StatusCode
Available on crate feature
http only.Sourceimpl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Triangle<T>
Available on crate feature geo-types only.
impl<T: CoordNum + Dummy<Faker>> Dummy<Faker> for Triangle<T>
Available on crate feature
geo-types only.Sourceimpl Dummy<Faker> for UrlSafeBase64Value
Available on crate feature base64 only.
impl Dummy<Faker> for UrlSafeBase64Value
Available on crate feature
base64 only.Auto Trait Implementations
impl Freeze for Faker
impl RefUnwindSafe for Faker
impl Send for Faker
impl Sync for Faker
impl Unpin for Faker
impl UnsafeUnpin for Faker
impl UnwindSafe for Faker